@@ -16,14 +16,12 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QLayout>
 #include <QTabWidget>
 
 #include <kaboutdata.h>
 #include <kcmodule.h>
-#include <kdialog.h>
 #include <KLocalizedString>
-
+#include <QVBoxLayout>
 #include "kcmsambaimports.h"
 #include "kcmsambalog.h"
 #include "kcmsambastatistics.h"
@@ -62,7 +60,7 @@ SambaContainer::SambaContainer(QWidget *parent, const QVariantList&) :
 	tabs.addTab(&imports, i18n("&Imports"));
 	tabs.addTab(&logView, i18n("&Log"));
 	tabs.addTab(&statisticsView, i18n("&Statistics"));
-	connect(&logView, SIGNAL(contentsChanged(QTreeWidget*,int,int)), &statisticsView, SLOT(setListInfo(QTreeWidget*,int,int)));
+	connect(&logView, &LogView::contentsChanged, &statisticsView, &StatisticsView::setListInfo);
 	setButtons(Help);
 
 	setQuickHelp(i18n("<p>The Samba and NFS Status Monitor is a front end to the programs"
